@@ -19,8 +19,8 @@
  * @brief State of a backup
  */
 
-#include "Date.h"
 #include <string>
+#include "Date.h"
 
 class Database;
 class Volume;
@@ -116,8 +116,10 @@ public:
    */
   inline bool operator<(const Backup &that) const {
     int c;
-    if((c = time - that.time)) return c < 0;
-    if((c = deviceName.compare(that.deviceName))) return c < 0;
+    if((c = time - that.time))
+      return c < 0;
+    if((c = deviceName.compare(that.deviceName)))
+      return c < 0;
     return false;
   }
 
@@ -134,8 +136,7 @@ public:
    * @param db Database to update
    * @param replace Replace existing row if present
    */
-  void insert(Database &db,
-              bool replace = false) const;
+  void insert(Database &db, bool replace = false) const;
 
   /** @brief Update this backup in the database
    * @param db Database to update
