@@ -16,12 +16,13 @@
 #include "rsbackup.h"
 #include "BackupPolicy.h"
 
+/** @brief The @c always backup policy; backups are made at every opportunity.
+ */
 class BackupPolicyAlways: public BackupPolicy {
 public:
   BackupPolicyAlways(): BackupPolicy("always") {}
 
-  void validate(const Volume *) const override {
-  }
+  void validate(const Volume *) const override {}
 
   bool backup(const Volume *, const Device *) const override {
     return true;
