@@ -1,4 +1,4 @@
-// Copyright © 2011, 2012, 2014-17, 2019 Richard Kettlewell.
+// Copyright © 2011, 2012, 2014-17, 2019, 2020 Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -13,6 +13,10 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <config.h>
+#include <cerrno>
+#include <regex>
+#include <sstream>
+#include <boost/filesystem.hpp>
 #include "rsbackup.h"
 #include "Conf.h"
 #include "Backup.h"
@@ -29,10 +33,6 @@
 #include "Device.h"
 #include "Indent.h"
 #include "BackupPolicy.h"
-#include <cerrno>
-#include <regex>
-#include <sstream>
-#include <boost/filesystem.hpp>
 
 Conf::Conf() {
   std::vector<std::string> args;
@@ -92,15 +92,15 @@ void Conf::write(std::ostream &os, int step, bool verbose) const {
   d(os, "", step);
 
   d(os, "# Command to run before accessing backup devices", step);
-  d(os, "#  pre-access-hook COMMAND ...", step);
-  if(preAccess.size())
-    os << indent(step) << "pre-access-hook " << quote(preAccess) << '\n';
+  d(os, "#  pre-device-hook COMMAND ...", step);
+  if(preDevice.size())
+    os << indent(step) << "pre-device-hook " << quote(preDevice) << '\n';
   d(os, "", step);
 
   d(os, "# Command to run after accessing backup devices", step);
-  d(os, "#  pre-access-hook COMMAND ...", step);
-  if(postAccess.size())
-    os << indent(step) << "post-access-hook " << quote(postAccess) << '\n';
+  d(os, "#  pre-device-hook COMMAND ...", step);
+  if(postDevice.size())
+    os << indent(step) << "post-device-hook " << quote(postDevice) << '\n';
   d(os, "", step);
 
   d(os, "# Names of backup devices", step);
@@ -109,6 +109,18 @@ void Conf::write(std::ostream &os, int step, bool verbose) const {
     os << "device " << quote(d.first) << '\n';
   d(os, "", step);
 
+  d(os, "# The time period to keep records of pruned backups for", step);
+  d(os, "#  keep-prune-logs INTERVAL", step);
+  os << indent(step) << "keep-prune-logs " << formatTimeInterval(keepPruneLogs)
+     << '\n';
+  d(os, "", step);
+
+  d(os, "# The maximum time to spend pruning", step);
+  d(os, "#  prune-timeout INTERVAL", step);
+  os << indent(step) << "prune-timeout " << formatTimeInterval(pruneTimeout)
+     << '\n';
+  d(os, "", step);
+
   d(os, "# ---- Reporting ----", step);
   d(os, "", step);
 
@@ -124,6 +136,13 @@ void Conf::write(std::ostream &os, int step, bool verbose) const {
   os << indent(step) << "sendmail " << quote(sendmail) << '\n';
   d(os, "", step);
 
+  if(rm != DEFAULT_RM) {
+    d(os, "# rm command", step);
+    d(os, "#  rm COMMAND", step);
+    os << indent(step) << "rm " << quote(rm) << '\n';
+    d(os, "", step);
+  }
+
   d(os, "# Stylesheet for HTML report", step);
   d(os, "#  stylesheet PATH", step);
   if(stylesheet.size())
@@ -141,7 +160,7 @@ void Conf::write(std::ostream &os, int step, bool verbose) const {
   d(os, "#   h3:HEADING        -- level-3 heading", step);
   d(os, "#   logs              -- logs of failed backups", step);
   d(os, "#   p:TEXT            -- arbitrary text", step);
-  d(os, "#   prune-logs[:DAYS] -- pruning logs (default 3 days)", step);
+  d(os, "#   prune-logs[:INTERVAL] -- pruning logs (default 3 days)", step);
   d(os, "#   summary           -- summary table", step);
   d(os, "#   title:TITLE       -- report title", step);
   d(os, "#   warnings          -- warning messages", step);
@@ -156,12 +175,14 @@ void Conf::write(std::ostream &os, int step, bool verbose) const {
 
   d(os, "# Graph background color", step);
   d(os, "#  color-graph-background 0xRRGGBB", step);
-  os << indent(step) << "color-graph-background 0x" << colorGraphBackground << '\n';
+  os << indent(step) << "color-graph-background 0x" << colorGraphBackground
+     << '\n';
   d(os, "", step);
 
   d(os, "# Graph foreground color", step);
   d(os, "#  color-graph-foreground 0xRRGGBB", step);
-  os << indent(step) << "color-graph-foreground 0x" << colorGraphForeground << '\n';
+  os << indent(step) << "color-graph-foreground 0x" << colorGraphForeground
+     << '\n';
   d(os, "", step);
 
   d(os, "# Graph month guide color", step);
@@ -182,7 +203,10 @@ void Conf::write(std::ostream &os, int step, bool verbose) const {
   d(os, "# Strategy for picking device colors", step);
   d(os, "#  device-color-strategy equidistant-value HUE", step);
   d(os, "#  device-color-strategy equidistant-value HUE SATURATION", step);
-  d(os, "#  device-color-strategy equidistant-value HUE SATURATION MINVALUE MAXVALUE", step);
+  d(os,
+    "#  device-color-strategy equidistant-value HUE SATURATION MINVALUE "
+    "MAXVALUE",
+    step);
   d(os, "#  device-color-strategy equidistant-hue HUE", step);
   d(os, "#  device-color-strategy equidistant-hue HUE SATURATION VALUE", step);
   os << indent(step) << "device-color-strategy "
@@ -201,12 +225,14 @@ void Conf::write(std::ostream &os, int step, bool verbose) const {
 
   d(os, "# Minimum width of a backup indicator", step);
   d(os, "#  backup-indicator-width PIXELS", step);
-  os << indent(step) << "backup-indicator-width " << backupIndicatorWidth << '\n';
+  os << indent(step) << "backup-indicator-width " << backupIndicatorWidth
+     << '\n';
   d(os, "", step);
 
   d(os, "# Minimum height of a backup indicator ", step);
   d(os, "#  backup-indicator-height PIXELS", step);
-  os << indent(step) << "backup-indicator-height " << backupIndicatorHeight << '\n';
+  os << indent(step) << "backup-indicator-height " << backupIndicatorHeight
+     << '\n';
   d(os, "", step);
 
   d(os, "# Target width graph of graph", step);
@@ -216,7 +242,8 @@ void Conf::write(std::ostream &os, int step, bool verbose) const {
 
   d(os, "# Width of a backup indicator in the device key", step);
   d(os, "#  backup-indicator-key-width PIXELS", step);
-  os << indent(step) << "backup-indicator-key-width " << backupIndicatorKeyWidth << '\n';
+  os << indent(step) << "backup-indicator-key-width " << backupIndicatorKeyWidth
+     << '\n';
   d(os, "", step);
 
   d(os, "# Font description for host names", step);
@@ -270,21 +297,20 @@ void Conf::readOneFile(const std::string &path) {
   std::string line;
   int lineno = 0;
   while(input.readline(line)) {
-    ++lineno;                           // keep track of where we are
+    ++lineno; // keep track of where we are
     cc.path = path;
     cc.line = lineno;
     try {
       size_t indent;
       split(cc.bits, line, &indent);
-      if(!cc.bits.size())                  // skip blank lines
+      if(!cc.bits.size()) // skip blank lines
         continue;
       // Consider all the possible commands
       const ConfDirective *d = ConfDirective::find(cc.bits[0]);
       if(d) {
         unsigned level = indenter.check(d->acceptable_levels, indent);
         switch(level) {
-        case 0:
-          throw SyntaxError("inconsistent indentation");
+        case 0: throw SyntaxError("inconsistent indentation");
         case LEVEL_TOP:
           cc.context = this;
           cc.host = nullptr;
@@ -294,11 +320,8 @@ void Conf::readOneFile(const std::string &path) {
           cc.context = cc.host;
           cc.volume = nullptr;
           break;
-        case LEVEL_VOLUME:
-          cc.context = cc.volume;
-          break;
-        default:
-          throw std::logic_error("unexpected indent level");
+        case LEVEL_VOLUME: cc.context = cc.volume; break;
+        default: throw std::logic_error("unexpected indent level");
         }
         d->check(cc);
         d->set(cc);
@@ -325,9 +348,7 @@ void Conf::includeFile(const std::string &path) {
     std::vector<std::string> files;
     Directory::getFiles(path, files);
     for(auto &name: files) {
-      if(!name.size()
-         || name.at(0) == '.'
-         || name.at(0) == '#'
+      if(!name.size() || name.at(0) == '.' || name.at(0) == '#'
          || name.find('~') != std::string::npos)
         continue;
       std::string fullname = path + PATH_SEP + name;
@@ -366,8 +387,7 @@ void Conf::selectHost(const std::string &hostName, bool sense) {
 
 // (De-)select one volume (or all if volumeName="*")
 void Conf::selectVolume(const std::string &hostName,
-                        const std::string &volumeName,
-                        bool sense) {
+                        const std::string &volumeName, bool sense) {
   if(volumeName == "*") {
     selectHost(hostName, sense);
   } else {
@@ -377,8 +397,8 @@ void Conf::selectVolume(const std::string &hostName,
     Host *host = hosts_iterator->second;
     auto volumes_iterator = host->volumes.find(volumeName);
     if(volumes_iterator == host->volumes.end())
-      throw CommandError("no such volume as '" + hostName
-                         + ":" + volumeName + "'");
+      throw CommandError("no such volume as '" + hostName + ":" + volumeName
+                         + "'");
     volumes_iterator->second->select(sense);
   }
 }
@@ -415,14 +435,32 @@ void Conf::readState() {
   const bool progress = (globalWarningMask & WARNING_VERBOSE) && isatty(2);
   std::vector<std::string> upgraded;
 
+  // Detect old-format logfiles and error if present
+  if(boost::filesystem::exists(logs)) {
+    Directory::getFiles(logs, files);
+    std::regex logfileRegexp(
+        "^([0-9]+-[0-9]+-[0-9]+)-([^-]+)-([^-]+)-([^-]+)\\.log$");
+    int oldFiles = 0;
+    for(size_t n = 0; n < files.size(); ++n) {
+      std::smatch mr;
+      if(!std::regex_match(files[n], mr, logfileRegexp))
+        continue;
+      ++oldFiles;
+    }
+    if(oldFiles)
+      throw SystemError("old format logs exist, you must use a release between "
+                        "2.0 and 6.0 to upgrade");
+  }
+
   std::string log;
   // Read database contents
   // Better would be to read only the rows required, on demand.
   {
-    Database::Statement stmt(getdb(),
-                             "SELECT host,volume,device,id,time,pruned,rc,status,log"
-                             " FROM backup",
-                             SQL_END);
+    Database::Statement stmt(
+        getdb(),
+        "SELECT host,volume,device,id,time,pruned,rc,status,log"
+        " FROM backup",
+        SQL_END);
     while(stmt.next()) {
       Backup backup;
       hostName = stmt.get_string(0);
@@ -437,102 +475,13 @@ void Conf::readState() {
       addBackup(backup, hostName, volumeName);
     }
   }
-
-  // Upgrade old-format logfiles
-  if(boost::filesystem::exists(logs)) {
-    Directory::getFiles(logs, files);
-    std::regex logfileRegexp("^([0-9]+-[0-9]+-[0-9]+)-([^-]+)-([^-]+)-([^-]+)\\.log$");
-    for(size_t n = 0; n < files.size(); ++n) {
-      if(progress)
-        progressBar(IO::err, "Upgrading old logs", n, files.size());
-      // Parse the filename
-      std::smatch mr;
-      if(!std::regex_match(files[n], mr, logfileRegexp))
-        continue;
-      Backup backup;
-      backup.id = mr[1];
-      backup.time = Date(mr[1]).toTime();
-      backup.deviceName = mr[2];
-      hostName = mr[3];
-      volumeName = mr[4];
-
-      // Read the log
-      IO input;
-      std::vector<std::string> contents;
-      input.open(logs + "/" + files[n], "r");
-      input.readlines(contents);
-      // Skip empty files
-      if(contents.size() == 0) {
-        if(progress)
-          progressBar(IO::err, nullptr, 0, 0);
-        warning(WARNING_ALWAYS, "empty file: %s", files[n].c_str());
-        continue;
-      }
-      // Find the status code
-      const std::string &last = contents[contents.size() - 1];
-      backup.rc = -1;
-      if(last.compare(0, 3, "OK:") == 0)
-        backup.rc = 0;
-      else {
-        std::string::size_type pos = last.rfind("error=");
-        if(pos < std::string::npos)
-          sscanf(last.c_str() + pos + 6, "%i", &backup.rc);
-      }
-      if(last.rfind("pruning") != std::string::npos)
-        backup.setStatus(PRUNING);
-      else if(backup.rc == 0)
-        backup.setStatus(COMPLETE);
-      else
-        backup.setStatus(FAILED);
-      for(std::string &c: contents) {
-        backup.contents += c;
-        backup.contents += "\n";
-      }
-
-      addBackup(backup, hostName, volumeName, true);
-
-      if(globalCommand.act) {
-        // addBackup might fail to set volume
-        if(backup.volume != nullptr) {
-          if(upgraded.size() == 0)
-            getdb().begin();
-          try {
-            backup.insert(getdb());
-          } catch(DatabaseError &e) {
-            if(e.status != SQLITE_CONSTRAINT)
-              throw;
-          }
-          upgraded.push_back(files[n]);
-        } else {
-          if(progress)
-            progressBar(IO::err, nullptr, 0, 0);
-          warning(WARNING_ALWAYS, "cannot upgrade %s", files[n].c_str());
-        }
-      }
-    }
-    logsRead = true;
-    if(globalCommand.act && upgraded.size()) {
-      getdb().commit();
-      bool upgradeFailure = false;
-      for(std::string &u: upgraded) {
-        const std::string path = logs + "/" + u;
-        if(unlink(path.c_str())) {
-          error("removing %s: %s", path.c_str(), strerror(errno));
-          upgradeFailure = true;
-        }
-      }
-      if(upgradeFailure)
-        throw SystemError("could not remove old logfiles");
-    }
-  }
+  logsRead = true;
   if(progress)
     progressBar(IO::err, nullptr, 0, 0);
 }
 
-void Conf::addBackup(Backup &backup,
-                     const std::string &hostName,
-                     const std::string &volumeName,
-                     bool forceWarn) {
+void Conf::addBackup(Backup &backup, const std::string &hostName,
+                     const std::string &volumeName, bool forceWarn) {
   const bool progress = (globalWarningMask & WARNING_VERBOSE) && isatty(2);
   unsigned warning_type = forceWarn ? WARNING_ALWAYS : WARNING_UNKNOWN;
 
@@ -544,8 +493,7 @@ void Conf::addBackup(Backup &backup,
     if(!contains(unknownDevices, backup.deviceName)) {
       if(progress)
         progressBar(IO::err, nullptr, 0, 0);
-      warning(warning_type,
-              "unknown device %s", backup.deviceName.c_str());
+      warning(warning_type, "unknown device %s", backup.deviceName.c_str());
       unknownDevices.insert(backup.deviceName);
       ++globalConfig.unknownObjects;
     }
@@ -555,24 +503,26 @@ void Conf::addBackup(Backup &backup,
   // about it once.
   Host *host = findHost(hostName);
   if(!host) {
-    if(!contains(unknownHosts, hostName)) {
+    if(!contains(unknownHosts, std::pair<std::string, std::string>{
+                                   hostName, backup.deviceName})) {
       if(progress)
         progressBar(IO::err, nullptr, 0, 0);
       warning(warning_type, "unknown host %s", hostName.c_str());
-      unknownHosts.insert(hostName);
       ++globalConfig.unknownObjects;
+      unknownHosts.insert({hostName, backup.deviceName});
     }
     return;
   }
   Volume *volume = host->findVolume(volumeName);
   if(!volume) {
-    if(!contains(host->unknownVolumes, volumeName)) {
+    if(!contains(host->unknownVolumes, std::pair<std::string, std::string>{
+                                           volumeName, backup.deviceName})) {
       if(progress)
         progressBar(IO::err, nullptr, 0, 0);
-      warning(warning_type, "unknown volume %s:%s",
-              hostName.c_str(), volumeName.c_str());
-      host->unknownVolumes.insert(volumeName);
+      warning(warning_type, "unknown volume %s:%s", hostName.c_str(),
+              volumeName.c_str());
       ++globalConfig.unknownObjects;
+      host->unknownVolumes.insert({volumeName, backup.deviceName});
     }
     return;
   }
