@@ -1,5 +1,5 @@
 // -*-C++-*-
-// Copyright © 2011, 2012, 2014-2016, 2019 Richard Kettlewell.
+// Copyright © 2011, 2012, 2014-2016, 2019, 2020 Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -55,23 +55,44 @@ class Volume;
 class Database;
 class Backup;
 
+/** @brief Compare two strings as names
+ * @param a First string
+ * @param b Second string
+ * @return true if @p a < @p b
+ *
+ * Comparison treats embedded numbers specially.
+ */
+bool namelt(const std::string &a, const std::string &b);
+
+/** @brief Function type to allow @ref namelt to be used by STL containers */
+struct namelt_type {
+  /** @brief Compare two strings as names
+   * @param a First string
+   * @param b Second string
+   * @return true if @p a < @p b
+   */
+  bool operator()(const std::string &a, const std::string &b) const {
+    return namelt(a, b);
+  }
+};
+
 /** @brief Type of map from host names to hosts
  *
  * @see Conf::hosts
  */
-typedef std::map<std::string, Host *> hosts_type;
+typedef std::map<std::string, Host *, namelt_type> hosts_type;
 
 /** @brief Type of map from store names to stores
  *
  * @see Conf::stores
  */
-typedef std::map<std::string, Store *> stores_type;
+typedef std::map<std::string, Store *, namelt_type> stores_type;
 
 /** @brief Type of map from device names to devices
  *
  * @see Conf::devices
  **/
-typedef std::map<std::string, Device *> devices_type;
+typedef std::map<std::string, Device *, namelt_type> devices_type;
 
 /** @brief Root node of the entire configuration and state of rsbackup. */
 class Conf: public ConfBase {
@@ -118,14 +139,20 @@ public:
   /** @brief Age to keep pruning logs */
   int keepPruneLogs = DEFAULT_KEEP_PRUNE_LOGS;
 
+  /** @brief Maximum time to spend pruning */
+  int pruneTimeout = DEFAULT_PRUNE_TIMEOUT;
+
   /** @brief Path to @c sendmail */
   std::string sendmail = DEFAULT_SENDMAIL;
 
+  /** @brief @c rm command (overridden for testing only) */
+  std::string rm = DEFAULT_RM;
+
   /** @brief Pre-access hook */
-  std::vector<std::string> preAccess;
+  std::vector<std::string> preDevice;
 
   /** @brief Post-access hook */
-  std::vector<std::string> postAccess;
+  std::vector<std::string> postDevice;
 
   /** @brief Path to stylesheet for HTML report output
    *
@@ -140,19 +167,19 @@ public:
   Color colorBad = COLOR_BAD;
 
   /** @brief Foregroud color of graph */
-  Color colorGraphForeground = { 0, 0, 0 };
+  Color colorGraphForeground = {0, 0, 0};
 
   /** @brief Background color of graph */
-  Color colorGraphBackground = { 1, 1, 1 };
+  Color colorGraphBackground = {1, 1, 1};
 
   /** @brief Color of vertical bars repsenting months in graph */
-  Color colorMonthGuide = { 0.96875, 0.96875, 0.96875 };
+  Color colorMonthGuide = {0.96875, 0.96875, 0.96875};
 
   /** @brief Color of horizontal lines between hosts in graph */
-  Color colorHostGuide = { 0.875, 0.875, 0.875 };
+  Color colorHostGuide = {0.875, 0.875, 0.875};
 
   /** @brief Color of horizontal lines between volumes in graph */
-  Color colorVolumeGuide = { 0.9375, 0.9375, 0.9375 };
+  Color colorVolumeGuide = {0.9375, 0.9375, 0.9375};
 
   /** @brief Horizontal padding in graph */
   double horizontalPadding = 8;
@@ -188,28 +215,23 @@ public:
   std::string timeLabelFont = "Normal";
 
   /** @brief List of report sections */
-  std::vector<std::string> report = {
-    "title:Backup report (${RSBACKUP_DATE})",
-    "h1:Backup report (${RSBACKUP_DATE})",
-    "h2:Warnings?warnings",
-    "warnings",
-    "h2:Summary",
-    "summary",
-    "history-graph",
-    "h2:Logfiles",
-    "logs",
-    "h3:Pruning logs",
-    "prune-logs",
-    "p:Generated ${RSBACKUP_CTIME}"
-  };
+  std::vector<std::string> report = {"title:Backup report (${RSBACKUP_DATE})",
+                                     "h1:Backup report (${RSBACKUP_DATE})",
+                                     "h2:Warnings?warnings",
+                                     "warnings",
+                                     "h2:Summary",
+                                     "summary",
+                                     "history-graph",
+                                     "h2:Logfiles",
+                                     "logs",
+                                     "h3:Pruning logs",
+                                     "prune-logs",
+                                     "p:Generated ${RSBACKUP_CTIME}"};
 
   /** @brief Layout of graph */
   std::vector<std::string> graphLayout = {
-    "host-labels:0,0",
-    "volume-labels:1,0",
-    "content:2,0",
-    "time-labels:2,1",
-    "device-key:2,3:RC",
+      "host-labels:0,0", "volume-labels:1,0", "content:2,0",
+      "time-labels:2,1", "device-key:2,3:RC",
   };
 
   /** @brief Read the master configuration file
@@ -226,8 +248,7 @@ public:
    * @param volumeName Name of volume to select or "*" for all
    * @param sense True to select, false to dselect
    */
-  void selectVolume(const std::string &hostName,
-                    const std::string &volumeName,
+  void selectVolume(const std::string &hostName, const std::string &volumeName,
                     bool sense = true);
 
   /** @brief Add a host
@@ -276,11 +297,12 @@ public:
    */
   std::set<std::string> unknownDevices;
 
-  /** @brief Unrecognized host names found in logs
+  /** @brief Unrecognized host names found in logs, mapped to devices that
+   * mention them
    *
    * Set by readState().
    */
-  std::set<std::string> unknownHosts;
+  std::set<std::pair<std::string, std::string>> unknownHosts;
 
   /** @brief Total number of unknown objects
    *
@@ -299,8 +321,7 @@ public:
 
   std::string what() const override;
 
-  void write(std::ostream &os, int step, bool verbose)
-    const override;
+  void write(std::ostream &os, int step, bool verbose) const override;
 
 private:
   /** @brief Read a single configuration file
@@ -316,8 +337,8 @@ private:
    * @throws ConfigError if the contents of a file are malformed
    *
    * If @p path is a directory then the files in it are read (via @ref
-   * readOneFile; there is no recursion).  Dotfiles and backup files (indicated
-   * by a trailing "~") are skipped.
+   * readOneFile; there is no recursion).  Dotfiles and backup files
+   * (indicated by a trailing "~") are skipped.
    *
    * Otherwise the behavior is the same as @ref readOneFile().
    */
@@ -336,8 +357,7 @@ private:
    * If @p hostName is @c * then all hosts are (de-)selected, as by @ref
    * selectAll().
    */
-  void selectHost(const std::string &hostName,
-                  bool sense = true);
+  void selectHost(const std::string &hostName, bool sense = true);
 
   /** @brief Set to @c true when logfiles have been read
    * Set by @ref readState().
@@ -361,15 +381,13 @@ private:
    * @param volumeName Volume owning @p backup
    * @param forceWarn Force warnings on.
    *
-   * Identifies the volume from the parameters, fills in @p Backup::volume, and
-   * adds the backup to the volume's list of backups.  If the backup belongs to
-   * an unknown device, host or volume, logs this but does not add it to
-   * anything.
+   * Identifies the volume from the parameters, fills in @p Backup::volume,
+   * and adds the backup to the volume's list of backups.  If the backup
+   * belongs to an unknown device, host or volume, logs this but does not add
+   * it to anything.
    */
-  void addBackup(Backup &backup,
-                 const std::string &hostName,
-                 const std::string &volumeName,
-                 bool forceWarn = false);
+  void addBackup(Backup &backup, const std::string &hostName,
+                 const std::string &volumeName, bool forceWarn = false);
 };
 
 /** @brief Global configuration */
