@@ -1,5 +1,5 @@
 // -*-C++-*-
-// Copyright © 2011, 2012, 2014, 2015, 2018 Richard Kettlewell.
+// Copyright © 2011, 2012, 2014, 2015, 2018, 2020 Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,15 +20,15 @@
  */
 
 #if HAVE_PATHS_H
-# include <paths.h>
+#include <paths.h>
 #endif
 
 /** @cond fixup */
 #ifndef _PATH_DEVNULL
-# define _PATH_DEVNULL "/dev/null"
+#define _PATH_DEVNULL "/dev/null"
 #endif
 #ifndef _PATH_SENDMAIL
-# define _PATH_SENDMAIL "/usr/sbin/sendmail"
+#define _PATH_SENDMAIL "/usr/sbin/sendmail"
 #endif
 /** @endcond */
 
@@ -38,19 +38,19 @@
 #define DEFAULT_CONFIG "/etc/rsbackup/config"
 
 /** @brief Default maximum age */
-#define DEFAULT_MAX_AGE 3
+#define DEFAULT_MAX_AGE (3 * 86400)
 
 /** @brief Default minimum backups */
 #define DEFAULT_MIN_BACKUPS "1"
 
 /** @brief Default pruning age */
-#define DEFAULT_PRUNE_AGE "366"
+#define DEFAULT_PRUNE_AGE "366d"
 
 /** @brief Default pruning age */
-#define DEFAULT_DECAY_START "1"
+#define DEFAULT_DECAY_START "1d"
 
 /** @brief Default decay window size */
-#define DEFAULT_DECAY_WINDOW "1"
+#define DEFAULT_DECAY_WINDOW "1d"
 
 /** @brief Default decay scale */
 #define DEFAULT_DECAY_SCALE "2"
@@ -79,14 +79,21 @@
 /** @brief Default SSH timeout */
 #define DEFAULT_SSH_TIMEOUT 60
 
-/** @brief Default days to keep pruning logs */
-#define DEFAULT_KEEP_PRUNE_LOGS 31
+/** @brief Default pruning timeout */
+#define DEFAULT_PRUNE_TIMEOUT 0
+
+/** @brief Default period to keep pruning logs */
+#define DEFAULT_KEEP_PRUNE_LOGS (31 * 86400)
 
 /** @brief Default path to email injector */
 #define DEFAULT_SENDMAIL _PATH_SENDMAIL
 
+/** @brief Default  rm */
+#define DEFAULT_RM "rm"
+
 /** @brief Default warning mask */
-#define DEFAULT_WARNING_MASK (WARNING_DEPRECATED|WARNING_PARTIAL|WARNING_ERRORLOGS|WARNING_DATABASE)
+#define DEFAULT_WARNING_MASK                                                   \
+  (WARNING_DEPRECATED | WARNING_PARTIAL | WARNING_ERRORLOGS | WARNING_DATABASE)
 
 /* Colors */
 
