@@ -1,5 +1,5 @@
 //-*-C++-*-
-// Copyright © 2015, 2016 Richard Kettlewell.
+// Copyright © 2015, 2016, 2020 Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -118,8 +118,8 @@ public:
    * (In contrast to the read/write methods) the event loop stops waiting for
    * the process before this call is made.
    */
-  virtual void onWait(EventLoop *e, pid_t pid,
-                      int status, const struct rusage &ru);
+  virtual void onWait(EventLoop *e, pid_t pid, int status,
+                      const struct rusage &ru);
 };
 
 /** @brief An event loop supporting asynchronous I/O
@@ -202,6 +202,9 @@ public:
    */
   void wait(bool wait_for_timeouts = false);
 
+  /** @brief Send all current subprocesses SIGTERM */
+  void terminateSubprocesses();
+
 private:
   /** @brief File descriptors monitored for reading */
   std::map<int, Reactor *> readers;
