@@ -24,7 +24,7 @@
 /** @brief Type of map from volume names to volumes
  * @see Host::volumes
  */
-typedef std::map<std::string, Volume *> volumes_type;
+typedef std::map<std::string, Volume *, namelt_type> volumes_type;
 
 /** @brief Represents a host */
 class Host: public ConfBase {
@@ -34,11 +34,8 @@ public:
    * @param name_ Name of host
    */
   Host(Conf *parent_, const std::string &name_):
-    ConfBase(static_cast<ConfBase *>(parent_)),
-    parent(parent_),
-    name(name_),
-    group(name_),
-    hostname(name_) {
+      ConfBase(static_cast<ConfBase *>(parent_)), parent(parent_), name(name_),
+      group(name_), hostname(name_) {
     parent->addHost(this);
   }
 
@@ -63,17 +60,16 @@ public:
   /** @brief Remote hostname */
   std::string hostname;
 
-  /** @brief True if host is expected to always be up */
-  bool alwaysUp = false;
-
   /** @brief Priority of this host */
   int priority = 0;
 
   /** @brief Unrecognized volume names found in logs
+   *
+   * Maps volume names to device names.
    *
    * Set by Conf::readState().
    */
-  std::set<std::string> unknownVolumes;
+  std::set<std::pair<std::string, std::string>> unknownVolumes;
 
   /** @brief Test whether host is selected
    * @return True if any volume for this host is selected
@@ -131,8 +127,7 @@ public:
 
   std::string what() const override;
 
-  void write(std::ostream &os, int step, bool verbose)
-    const override;
+  void write(std::ostream &os, int step, bool verbose) const override;
 };
 
 #endif /* HOST_H */
