@@ -54,10 +54,10 @@ setup() {
 
   echo "public true" >> ${WORKSPACE}/config
 
-  echo "pre-access-hook ${srcdir:-.}/hook" >> ${WORKSPACE}/config
-  echo "post-access-hook ${srcdir:-.}/hook" >> ${WORKSPACE}/config
+  echo "pre-device-hook ${srcdir:-.}/hook" >> ${WORKSPACE}/config
+  echo "post-device-hook ${srcdir:-.}/hook" >> ${WORKSPACE}/config
 
-  echo "keep-prune-logs 1" >> ${WORKSPACE}/config
+  echo "keep-prune-logs 1d" >> ${WORKSPACE}/config
   echo "backup-policy ${BACKUP_POLICY}" >> ${WORKSPACE}/config
   [ -n "$BACKUP_INTERVAL" ] && echo "backup-parameter min-interval ${BACKUP_INTERVAL}" >> ${WORKSPACE}/config
   echo "prune-policy ${PRUNE_POLICY}" >> ${WORKSPACE}/config
@@ -87,11 +87,11 @@ setup() {
 
   echo "host host1" >> ${WORKSPACE}/config
   echo "  hostname localhost" >> ${WORKSPACE}/config
-  [ "${PRUNE_AGE}" != none ] && echo "  ${PRUNE_AGE} 2" >> ${WORKSPACE}/config
+  [ "${PRUNE_AGE}" != none ] && echo "  ${PRUNE_AGE} 2d" >> ${WORKSPACE}/config
   echo "  volume volume1 ${WORKSPACE}/volume1" >> ${WORKSPACE}/config
   [ "${MIN_BACKUPS}" != none ] && echo "    ${MIN_BACKUPS} 1" >> ${WORKSPACE}/config
-  echo "    pre-backup-hook ${srcdir:-.}/hook" >> ${WORKSPACE}/config
-  echo "    post-backup-hook ${srcdir:-.}/hook" >> ${WORKSPACE}/config
+  echo "    pre-volume-hook ${srcdir:-.}/hook" >> ${WORKSPACE}/config
+  echo "    post-volume-hook ${srcdir:-.}/hook" >> ${WORKSPACE}/config
   echo "    check-file file1" >> ${WORKSPACE}/config
   echo "  volume volume2 ${WORKSPACE}/volume2" >> ${WORKSPACE}/config
   [ "${MIN_BACKUPS}" != none ] && echo "    ${MIN_BACKUPS} 2" >> ${WORKSPACE}/config
